Module scripts

Module scripts 

Scripts to block;

Statics

URL_IGNORE_CSS
Ignore list of CSS resources.
URL_IGNORE_EMBEDED_TRIE
Ignore list of scripts embedded or font extra.
URL_IGNORE_SCRIPT_BASE_PATHS
Ignore list of path scripts to ignore for tracking and analytics.
URL_IGNORE_SCRIPT_STYLES_PATHS
Ignore list of path scripts to ignore for themes.
URL_IGNORE_TRIE
Ignore list of scripts.
URL_IGNORE_TRIE_PATHS
Ignore list of scripts paths.